@@ -18,10 +18,10 @@
 #include <gtest/gtest.h>
 #include <fstream>
 #include <string>
-#include <gz/common/Console.hh>
-#include <gz/common/Filesystem.hh>
-#include <gz/common/Util.hh>
-#include "gz/fuel_tools/ClientConfig.hh"
+#include <ignition/common/Console.hh>
+#include <ignition/common/Filesystem.hh>
+#include <ignition/common/Util.hh>
+#include "ignition/fuel_tools/ClientConfig.hh"
 #include "test/test_config.h"
 
 using namespace ignition;
@@ -30,29 +30,29 @@ using namespace fuel_tools;
 /////////////////////////////////////////////////
 /// \brief Helper to remove file according to OS, while Windows
 /// has this issue:
-/// https://github.com/gazebosim/gz-common/issues/51
+/// https://github.com/ignitionrobotics/ign-common/issues/51
 /// \todo(anyone) Remove this once Windows issue is solved.
 /// \param[in] _path Path to file to be removed.
 void removeFileTemp(const std::string &_path)
 {
 #ifndef _WIN32
-  EXPECT_TRUE(common::removeFile(_path));
+  EXPECT_TRUE(ignition::common::removeFile(_path));
 #else
-  common::removeFile(_path);
+  ignition::common::removeFile(_path);
 #endif
 }
 
 /////////////////////////////////////////////////
 /// \brief Get home directory.
 /// \return Home directory or empty string if home wasn't found.
-/// \ToDo: Move this function to common::Filesystem
+/// \ToDo: Move this function to ignition::common::Filesystem
 std::string homePath()
 {
   std::string homePath;
 #ifndef _WIN32
-  common::env("HOME", homePath);
+  ignition::common::env("HOME", homePath);
 #else
-  common::env("USERPROFILE", homePath);
+  ignition::common::env("USERPROFILE", homePath);
 #endif
 
   return homePath;
@@ -61,7 +61,7 @@ std::string homePath()
 /////////////////////////////////////////////////
 /// \brief Get cache directory.
 /// \return Cache directory
-/// \ToDo: Move this function to common::Filesystem
+/// \ToDo: Move this function to ignition::common::Filesystem
 std::string cachePath()
 {
 #ifndef _WIN32
@@ -76,7 +76,7 @@ std::string cachePath()
 TEST(ClientConfig, InitiallyDefaultServers)
 {
   ClientConfig config;
-  EXPECT_EQ(2u, config.Servers().size());
+  EXPECT_EQ(1u, config.Servers().size());
 }
 
 /////////////////////////////////////////////////
@@ -88,7 +88,7 @@ TEST(ClientConfig, ServersCanBeAdded)
   srv.SetUrl(common::URI("http://asdf"));
   config.AddServer(srv);
 
-  ASSERT_EQ(3u, config.Servers().size());
+  ASSERT_EQ(2u, config.Servers().size());
   EXPECT_EQ(std::string("http://asdf"), config.Servers().back().Url().Str());
 }
 
@@ -97,13 +97,11 @@ TEST(ClientConfig, ServersCanBeAdded)
 TEST(ClientConfig, CustomDefaultConfiguration)
 {
   ClientConfig config;
-  ASSERT_EQ(2u, config.Servers().size());
-  EXPECT_EQ("https://fuel.gazebosim.org",
-    config.Servers().front().Url().Str());
+  ASSERT_EQ(1u, config.Servers().size());
   EXPECT_EQ("https://fuel.ignitionrobotics.org",
-    config.Servers()[1].Url().Str());
+    config.Servers().front().Url().Str());
 
-  std::string defaultCacheLocation = common::joinPaths(
+  std::string defaultCacheLocation = ignition::common::joinPaths(
     homePath(), ".ignition", "fuel");
   EXPECT_EQ(defaultCacheLocation, config.CacheLocation());
 }
@@ -136,13 +134,11 @@ TEST(ClientConfig, CustomConfiguration)
 
   EXPECT_TRUE(config.LoadConfig(testPath));
 
-  ASSERT_EQ(4u, config.Servers().size());
-  EXPECT_EQ("https://fuel.gazebosim.org",
-    config.Servers().front().Url().Str());
+  ASSERT_EQ(3u, config.Servers().size());
   EXPECT_EQ("https://fuel.ignitionrobotics.org",
-    config.Servers()[1].Url().Str());
+    config.Servers().front().Url().Str());
   EXPECT_EQ("https://api.ignitionfuel.org",
-    config.Servers()[2].Url().Str());
+    config.Servers()[1].Url().Str());
   EXPECT_EQ("https://myserver",
     config.Servers().back().Url().Str());
 
@@ -166,10 +162,10 @@ TEST(ClientConfig, RepeatedServerConfiguration)
       << "# The list of servers."                 << std::endl
       << "servers:"                               << std::endl
       << "  -"                                    << std::endl
-      << "    url: https://fuel.gazebosim.org"  << std::endl
+      << "    url: https://fuel.ignitionrobotics.org"  << std::endl
       << ""                                       << std::endl
       << "  -"                                    << std::endl
-      << "    url: https://fuel.gazebosim.org"  << std::endl
+      << "    url: https://fuel.ignitionrobotics.org"  << std::endl
       << ""                                       << std::endl
       << "# Where are the assets stored in disk." << std::endl
       << "cache:"                                 << std::endl
@@ -317,7 +313,7 @@ TEST(ClientConfig, AsString)
 #else
     EXPECT_NE(str.find(".ignition\\fuel"), std::string::npos);
 #endif
-    EXPECT_NE(str.find("https://fuel.gazebosim.org"), std::string::npos);
+    EXPECT_NE(str.find("https://fuel.ignitionrobotics.org"), std::string::npos);
   }
 
   {
@@ -410,15 +406,17 @@ TEST(ServerConfig, Url)
     EXPECT_EQ("http://banana:8080", srv.Url().Str());
     EXPECT_EQ("http", srv.Url().Scheme());
     EXPECT_EQ("banana:8080", srv.Url().Path().Str());
+    EXPECT_FALSE(srv.Url().Authority());
   }
 
   // Trailing /
   {
     ServerConfig srv;
     srv.SetUrl(common::URI("http://banana:8080/"));
-    EXPECT_EQ("http://banana:8080", srv.Url().Str());
+    EXPECT_EQ("http://banana:8080/", srv.Url().Str());
     EXPECT_EQ("http", srv.Url().Scheme());
-    EXPECT_EQ("banana:8080", srv.Url().Path().Str());
+    EXPECT_EQ("banana:8080/", srv.Url().Path().Str());
+    EXPECT_FALSE(srv.Url().Authority());
   }
 
   // Set from URI
@@ -432,6 +430,7 @@ TEST(ServerConfig, Url)
     EXPECT_EQ("http://banana:8080", srv.Url().Str());
     EXPECT_EQ("http", srv.Url().Scheme());
     EXPECT_EQ("banana:8080", srv.Url().Path().Str());
+    EXPECT_FALSE(srv.Url().Authority());
   }
 }
 
