@@ -19,7 +19,7 @@
 #pragma warning(push, 0)
 #endif
 #include <google/protobuf/text_format.h>
-#include <gz/msgs/fuel_metadata.pb.h>
+#include <ignition/msgs/fuel_metadata.pb.h>
 #ifdef _MSC_VER
 #pragma warning(pop)
 #endif
@@ -32,32 +32,32 @@
 #include <regex>
 #include <string>
 
-#include <gz/common/Console.hh>
-#include <gz/common/Filesystem.hh>
-#include <gz/common/URI.hh>
-#include <gz/common/Util.hh>
+#include <ignition/common/Console.hh>
+#include <ignition/common/Filesystem.hh>
+#include <ignition/common/Util.hh>
 
-#include <gz/msgs/Utility.hh>
+#include <ignition/msgs/Utility.hh>
 
-#include "gz/fuel_tools/ClientConfig.hh"
-#include "gz/fuel_tools/CollectionIdentifier.hh"
-#include "gz/fuel_tools/FuelClient.hh"
-#include "gz/fuel_tools/JSONParser.hh"
-#include "gz/fuel_tools/LocalCache.hh"
-#include "gz/fuel_tools/ModelIdentifier.hh"
-#include "gz/fuel_tools/ModelIterPrivate.hh"
-#include "gz/fuel_tools/RestClient.hh"
-#include "gz/fuel_tools/WorldIdentifier.hh"
-#include "gz/fuel_tools/WorldIterPrivate.hh"
+#include "ignition/fuel_tools/ClientConfig.hh"
+#include "ignition/fuel_tools/CollectionIdentifier.hh"
+#include "ignition/fuel_tools/FuelClient.hh"
+#include "ignition/fuel_tools/Helpers.hh"
+#include "ignition/fuel_tools/JSONParser.hh"
+#include "ignition/fuel_tools/LocalCache.hh"
+#include "ignition/fuel_tools/ModelIdentifier.hh"
+#include "ModelIterPrivate.hh"
+#include "ignition/fuel_tools/RestClient.hh"
+#include "ignition/fuel_tools/WorldIdentifier.hh"
+#include "WorldIterPrivate.hh"
 
 using namespace ignition;
 using namespace fuel_tools;
 
 /// \brief Private Implementation
-class gz::fuel_tools::FuelClientPrivate
+class ignition::fuel_tools::FuelClientPrivate
 {
   /// \brief A model URL,
-  /// E.g.: https://fuel.gazebosim.org/1.0/caguero/models/Beer/2
+  /// E.g.: https://fuel.ignitionrobotics.org/1.0/caguero/models/Beer/2
   /// Where the API version and the model version are optional.
   public: const std::string kModelUrlRegexStr{
     // Method
@@ -73,10 +73,12 @@ class gz::fuel_tools::FuelClientPrivate
     // Name
     "([^\\/]+)\\/*"
     // Version
-    "([0-9]*|tip)"};
+    "([0-9]*|tip)"
+    // Trailing /
+    "/?"};
 
   /// \brief A world URL,
-  /// E.g.: https://fuel.gazebosim.org/1.0/OpenRobotics/worlds/Empty/1
+  /// E.g.: https://fuel.ignitionrobotics.org/1.0/OpenRobotics/worlds/Empty/1
   /// Where the API version and the world version are optional.
   public: const std::string kWorldUrlRegexStr{
     // Method
@@ -92,7 +94,9 @@ class gz::fuel_tools::FuelClientPrivate
     // Name
     "([^\\/]+)\\/*"
     // Version
-    "([0-9]*|tip)"};
+    "([0-9]*|tip)"
+    // Trailing /
+    "/?"};
 
   /// \brief A model file URL,
   /// E.g.: https://server.org/1.0/owner/models/modelname/files/meshes/mesh.dae
@@ -115,7 +119,9 @@ class gz::fuel_tools::FuelClientPrivate
     // "files"
     "files\\/+"
     // File path
-    "(.*)"};
+    "(.*)"
+    // Trailing /
+    "/?"};
 
   /// \brief A world file URL,
   /// E.g.: https://server.org/1.0/owner/worlds/worldname/files/meshes/mesh.dae
@@ -138,11 +144,13 @@ class gz::fuel_tools::FuelClientPrivate
     // "files"
     "files\\/+"
     // File path
-    "(.*)"};
+    "(.*)"
+    // Trailing /
+    "/?"};
 
   /// \brief A collection URL,
   /// E.g.:
-  /// https://fuel.gazebosim.org/1.0/OpenRobotics/collections/TestColl
+  /// https://fuel.ignitionrobotics.org/1.0/OpenRobotics/collections/TestColl
   /// Where the API version is optional
   public: const std::string kCollectionUrlRegexStr{
     // Method
@@ -169,10 +177,12 @@ class gz::fuel_tools::FuelClientPrivate
   /// \param[in] _pathToModelDir Path to the model directory.
   /// \param[in] _id Model identifier information.
   /// \param[in] _private True if this model should be private.
-  /// \param[in] _form Form to fill.
+  /// \param[in] _owner Model owner name.
+  /// \param[out] _form Form to fill.
   /// \return True if the operation completed successfully.
   public: bool FillModelForm(const std::string &_pathToModelDir,
               const ModelIdentifier &_id, bool _private,
+              const std::string &_owner,
               std::multimap<std::string, std::string> &_form);
 
   /// \brief This function requests the available licenses from the
@@ -187,17 +197,6 @@ class gz::fuel_tools::FuelClientPrivate
   /// license information.
   public: void PopulateLicenses(const ServerConfig &_server);
 
-  /// \brief Checks the provided URI for fuel.gazebosim.org, and
-  /// prints a deprecation warning message if found.
-  /// \param[in] _uri URI to check
-  /// DEPRECATED/DEPRECATION: remove this function in Gazebo H.
-  public: void CheckForDeprecatedUri(const common::URI &_uri);
-
-  /// \brief Get zip data from a REST response. This is used by world and
-  /// model download.
-  public: void ZipFromResponse(const RestResponse &_resp,
-              std::string &_zip);
-
   /// \brief Client configuration
   public: ClientConfig config;
 
@@ -230,23 +229,31 @@ class gz::fuel_tools::FuelClientPrivate
 
 //////////////////////////////////////////////////
 FuelClient::FuelClient()
-  : FuelClient(ClientConfig(), Rest(), nullptr)
+  : FuelClient(ClientConfig(), Rest())
 {
 }
 
 //////////////////////////////////////////////////
-FuelClient::FuelClient(const ClientConfig &_config, const Rest &_rest,
-    LocalCache *_cache)
-  : dataPtr(new FuelClientPrivate)
+FuelClient::FuelClient(const ClientConfig &_config, const Rest &_rest)
+  : dataPtr(std::make_unique<FuelClientPrivate>())
 {
   this->dataPtr->config = _config;
   this->dataPtr->rest = _rest;
   this->dataPtr->rest.SetUserAgent(this->dataPtr->config.UserAgent());
 
-  if (nullptr == _cache)
-    this->dataPtr->cache.reset(new LocalCache(&(this->dataPtr->config)));
-  else
-    this->dataPtr->cache.reset(_cache);
+#ifndef _WIN32
+# pragma GCC diagnostic push
+# pragma GCC diagnostic ignored "-Wdeprecated-declarations"
+#else
+# pragma warning(push)
+# pragma warning(disable: 4996)
+#endif
+  this->dataPtr->cache = std::make_unique<LocalCache>(&(this->dataPtr->config));
+#ifndef _WIN32
+# pragma GCC diagnostic pop
+#else
+# pragma warning(pop)
+#endif
 
   this->dataPtr->urlModelRegex.reset(new std::regex(
     this->dataPtr->kModelUrlRegexStr));
@@ -260,6 +267,14 @@ FuelClient::FuelClient(const ClientConfig &_config, const Rest &_rest,
     this->dataPtr->kCollectionUrlRegexStr));
 }
 
+//////////////////////////////////////////////////
+FuelClient::FuelClient(const ClientConfig &_config, const Rest &_rest,
+      LocalCache *_cache) : FuelClient(_config, _rest)
+{
+  if (_cache != nullptr)
+    this->dataPtr->cache.reset(_cache);
+}
+
 //////////////////////////////////////////////////
 FuelClient::~FuelClient()
 {
@@ -282,7 +297,7 @@ Result FuelClient::ModelDetails(const ModelIdentifier &_id,
 Result FuelClient::ModelDetails(const ModelIdentifier &_id,
     ModelIdentifier &_model, const std::vector<std::string> &_headers) const
 {
-  Rest rest;
+  ignition::fuel_tools::Rest rest;
   RestResponse resp;
 
   auto serverUrl = _id.Server().Url().Str();
@@ -333,18 +348,30 @@ ModelIter FuelClient::Models(const ServerConfig &_server) const
 Result FuelClient::WorldDetails(const WorldIdentifier &_id,
     WorldIdentifier &_world) const
 {
+
+  return this->WorldDetails(_id, _world, {});
+}
+
+//////////////////////////////////////////////////
+Result FuelClient::WorldDetails(const WorldIdentifier &_id,
+    WorldIdentifier &_world, const std::vector<std::string> &_headers) const
+{
   auto serverUrl = _id.Server().Url().Str();
 
   if (serverUrl.empty() || _id.Owner().empty() || _id.Name().empty())
     return Result(ResultType::FETCH_ERROR);
 
-  Rest rest;
+  ignition::fuel_tools::Rest rest;
   RestResponse resp;
 
   auto version = _id.Server().Version();
   common::URIPath path;
   path = path / _id.Owner() / "worlds" / _id.Name();
 
+  std::vector<std::string> headersIncludingServerConfig = _headers;
+  AddServerConfigParametersToHeaders(
+    _id.Server(), headersIncludingServerConfig);
+
   resp = rest.Request(HttpMethod::GET, serverUrl, version,
       path.Str(), {}, {}, "");
   if (resp.statusCode != 200)
@@ -378,31 +405,16 @@ WorldIter FuelClient::Worlds(const ServerConfig &_server) const
 //////////////////////////////////////////////////
 ModelIter FuelClient::Models(const ModelIdentifier &_id)
 {
-  return this->Models(_id, true);
+  return const_cast<const FuelClient*>(this)->Models(_id);
 }
 
 //////////////////////////////////////////////////
 ModelIter FuelClient::Models(const ModelIdentifier &_id) const
 {
-  return this->Models(_id, true);
-}
-
-//////////////////////////////////////////////////
-ModelIter FuelClient::Models(const ModelIdentifier &_id, bool _checkCache)
-{
-  return const_cast<const FuelClient*>(this)->Models(_id, _checkCache);
-}
-
-//////////////////////////////////////////////////
-ModelIter FuelClient::Models(const ModelIdentifier &_id, bool _checkCache) const
-{
-  if (_checkCache)
-  {
-    // Check local cache first
-    ModelIter localIter = this->dataPtr->cache->MatchingModels(_id);
-    if (localIter)
-      return localIter;
-  }
+  // Check local cache first
+  ModelIter localIter = this->dataPtr->cache->MatchingModels(_id);
+  if (localIter)
+    return localIter;
 
   // TODO(nkoenig) try to fetch model directly from a server
   // Note: ign-fuel-server doesn't like URLs ending in /
@@ -413,7 +425,7 @@ ModelIter FuelClient::Models(const ModelIdentifier &_id, bool _checkCache) const
     path = path / _id.Owner() / "models";
 
   if (path.Str().empty())
-    return ModelIterFactory::Create();
+    return localIter;
 
   ignmsg << _id.UniqueName() << " not found in cache, attempting download\n";
 
@@ -463,12 +475,23 @@ Result FuelClient::UploadModel(const std::string &_pathToModelDir,
     const ModelIdentifier &_id, const std::vector<std::string> &_headers,
     bool _private)
 {
-  Rest rest;
+  return this->UploadModel(_pathToModelDir, _id, _headers, _private, "");
+}
+
+//////////////////////////////////////////////////
+Result FuelClient::UploadModel(const std::string &_pathToModelDir,
+    const ModelIdentifier &_id, const std::vector<std::string> &_headers,
+    bool _private, const std::string &_owner)
+{
+  ignition::fuel_tools::Rest rest;
   RestResponse resp;
 
   std::multimap<std::string, std::string> form;
-  if (!this->dataPtr->FillModelForm(_pathToModelDir, _id, _private, form))
+  if (!this->dataPtr->FillModelForm(_pathToModelDir, _id, _private, _owner,
+        form))
+  {
     return Result(ResultType::UPLOAD_ERROR);
+  }
 
   std::vector<std::string> headersIncludingServerConfig = _headers;
   AddServerConfigParametersToHeaders(
@@ -480,10 +503,26 @@ Result FuelClient::UploadModel(const std::string &_pathToModelDir,
 
   if (resp.statusCode != 200)
   {
+    std::string categories;
+    if (form.find("categories") != form.end())
+    {
+      categories = form.find("categories")->second;
+    }
+
     ignerr << "Failed to upload model." << std::endl
            << "  Server: " << _id.Server().Url().Str() << std::endl
+           << "  Server API Version: " <<  _id.Server().Version() << std::endl
            << "  Route: /models\n"
-           << "  REST response code: " << resp.statusCode << std::endl;
+           << "  Categories: " << categories << std::endl
+           << "  REST response code: " << resp.statusCode
+           << std::endl << std::endl
+           << "Suggestions" << std::endl
+           << "  1. Is the Server URL correct? Try entering it on a browser.\n"
+           << "  2. Do the categories exist? If you are using the Fuel server,"
+           << "     then you can get the complete list at"
+           << "     https://fuel.ignitionrobotics.org/1.0/categories.\n"
+           << "  3. If the owner is specified, make sure you have correct\n"
+           << "     permissions." << std::endl;
     return Result(ResultType::FETCH_ERROR);
   }
 
@@ -500,7 +539,7 @@ Result FuelClient::DeleteModel(const ModelIdentifier &)
 }
 
 void FuelClient::AddServerConfigParametersToHeaders(
-  const ServerConfig &_serverConfig,
+  const ignition::fuel_tools::ServerConfig &_serverConfig,
   std::vector<std::string> &_headers) const
 {
   bool privateTokenDefined = false;
@@ -521,12 +560,10 @@ void FuelClient::AddServerConfigParametersToHeaders(
 }
 
 //////////////////////////////////////////////////
-Result FuelClient::DeleteUrl(const gz::common::URI &_uri,
+Result FuelClient::DeleteUrl(const ignition::common::URI &_uri,
     const std::vector<std::string> &_headers)
 {
-  this->dataPtr->CheckForDeprecatedUri(_uri);
-
-  Rest rest;
+  ignition::fuel_tools::Rest rest;
   RestResponse resp;
 
   std::string server;
@@ -601,16 +638,12 @@ Result FuelClient::DownloadModel(const ModelIdentifier &_id,
   if(!res)
     return res;
 
-  for (ModelIdentifier dep : dependencies)
+  for (auto dep : dependencies)
   {
-    // Download dependency if not in the local cache
-    if (!this->dataPtr->cache->MatchingModel(dep))
-    {
-      auto dep_res = this->DownloadModel(dep, _headers);
+    auto dep_res = this->DownloadModel(dep, _headers);
 
-      if(!dep_res)
-        return dep_res;
-    }
+    if(!dep_res)
+      return dep_res;
   }
 
   return res;
@@ -628,7 +661,6 @@ Result FuelClient::DownloadModel(const ModelIdentifier &_id,
           << std::endl << _id.Server().AsString() << std::endl;
     return Result(ResultType::FETCH_ERROR);
   }
-  this->dataPtr->CheckForDeprecatedUri(_id.Server().Url());
 
   // Route
   common::URIPath route;
@@ -641,10 +673,10 @@ Result FuelClient::DownloadModel(const ModelIdentifier &_id,
   AddServerConfigParametersToHeaders(
     _id.Server(), headersIncludingServerConfig);
   // Request
-  Rest rest;
+  ignition::fuel_tools::Rest rest;
   RestResponse resp;
   resp = rest.Request(HttpMethod::GET, _id.Server().Url().Str(),
-      _id.Server().Version(), route.Str(), {"link=true"},
+      _id.Server().Version(), route.Str(), {},
       headersIncludingServerConfig, "");
   if (resp.statusCode != 200)
   {
@@ -678,12 +710,9 @@ Result FuelClient::DownloadModel(const ModelIdentifier &_id,
   }
   newId.SetVersion(version);
 
-  std::string zipData;
-  this->dataPtr->ZipFromResponse(resp, zipData);
-
   // Save
   // Note that the save function doesn't return the path
-  if (zipData.empty() || !this->dataPtr->cache->SaveModel(newId, zipData, true))
+  if (!this->dataPtr->cache->SaveModel(newId, resp.data, true))
     return Result(ResultType::FETCH_ERROR);
 
   return this->ModelDependencies(_id, _dependencies);
@@ -697,16 +726,16 @@ Result FuelClient::ModelDependencies(const ModelIdentifier &_id,
 
   // Locate any dependencies from the input model and download them.
   std::string path;
-  msgs::FuelMetadata meta;
-  if (this->CachedModel(common::URI(_id.UniqueName()), path))
+  ignition::msgs::FuelMetadata meta;
+  if (this->CachedModel(ignition::common::URI(_id.UniqueName()), path))
   {
     std::string metadataPath =
-      common::joinPaths(path, "metadata.pbtxt");
+      ignition::common::joinPaths(path, "metadata.pbtxt");
     std::string modelConfigPath =
-      common::joinPaths(path, "model.config");
+      ignition::common::joinPaths(path, "model.config");
 
-    bool foundMetadataPath = common::exists(metadataPath);
-    bool foundModelConfigPath = common::exists(modelConfigPath);
+    bool foundMetadataPath = ignition::common::exists(metadataPath);
+    bool foundModelConfigPath = ignition::common::exists(modelConfigPath);
 
     if (foundMetadataPath || foundModelConfigPath)
     {
@@ -725,7 +754,7 @@ Result FuelClient::ModelDependencies(const ModelIdentifier &_id,
       }
       else
       {
-        if (!msgs::ConvertFuelMetadata(inputStr, meta))
+        if (!ignition::msgs::ConvertFuelMetadata(inputStr, meta))
         {
           return Result(ResultType::UPLOAD_ERROR);
         }
@@ -733,7 +762,7 @@ Result FuelClient::ModelDependencies(const ModelIdentifier &_id,
 
       for (int i = 0; i < meta.dependencies_size(); ++i)
       {
-        common::URI dependencyURI(meta.dependencies(i).uri());
+        ignition::common::URI dependencyURI(meta.dependencies(i).uri());
 
         ModelIdentifier dependencyID;
         if(!this->ParseModelUrl(dependencyURI, dependencyID))
@@ -790,6 +819,13 @@ Result FuelClient::ModelDependencies(
 
 //////////////////////////////////////////////////
 Result FuelClient::DownloadWorld(WorldIdentifier &_id)
+{
+  return this->DownloadWorld(_id, {});
+}
+
+//////////////////////////////////////////////////
+Result FuelClient::DownloadWorld(WorldIdentifier &_id,
+    const std::vector<std::string> &_headers)
 {
   // Server config
   if (!_id.Server().Url().Valid() || _id.Server().Version().empty())
@@ -799,8 +835,6 @@ Result FuelClient::DownloadWorld(WorldIdentifier &_id)
     return Result(ResultType::FETCH_ERROR);
   }
 
-  this->dataPtr->CheckForDeprecatedUri(_id.Server().Url());
-
   // Route
   common::URIPath route;
   route = route / _id.Owner() / "worlds" / _id.Name() / _id.VersionStr() /
@@ -808,15 +842,15 @@ Result FuelClient::DownloadWorld(WorldIdentifier &_id)
 
   ignmsg << "Downloading world [" << _id.UniqueName() << "]" << std::endl;
 
-  std::vector<std::string> headersIncludingServerConfig;
+  std::vector<std::string> headersIncludingServerConfig = _headers;
   AddServerConfigParametersToHeaders(
     _id.Server(), headersIncludingServerConfig);
 
   // Request
-  Rest rest;
+  ignition::fuel_tools::Rest rest;
   RestResponse resp;
   resp = rest.Request(HttpMethod::GET, _id.Server().Url().Str(),
-      _id.Server().Version(), route.Str(), {"link=true"},
+      _id.Server().Version(), route.Str(), {},
       headersIncludingServerConfig, "");
   if (resp.statusCode != 200)
   {
@@ -850,12 +884,9 @@ Result FuelClient::DownloadWorld(WorldIdentifier &_id)
   }
   _id.SetVersion(version);
 
-  std::string zipData;
-  this->dataPtr->ZipFromResponse(resp, zipData);
-
   // Save
-  if (zipData.empty() || !this->dataPtr->cache->SaveWorld(_id, zipData, true))
-      return Result(ResultType::FETCH_ERROR);
+  if (!this->dataPtr->cache->SaveWorld(_id, resp.data, true))
+    return Result(ResultType::FETCH_ERROR);
 
   return Result(ResultType::FETCH);
 }
@@ -966,7 +997,7 @@ std::vector<FuelClient::ModelResult> FuelClient::DownloadModels(
 Result FuelClient::DownloadWorlds(
     const std::vector<WorldIdentifier> &_ids, size_t _jobs)
 {
-  std::deque<std::future<Result>> tasks;
+  std::deque<std::future<ignition::fuel_tools::Result>> tasks;
   // Check for finished tasks by checking if the status of their futures is
   // "ready". If a task is finished, check if it succeeded and print out an
   // error message if it failed. When a task is finished, it gets erased from
@@ -989,7 +1020,7 @@ Result FuelClient::DownloadWorlds(
     {
       for (auto taskIt = finishedIt; taskIt != tasks.end(); ++taskIt)
       {
-        Result result = taskIt->get();
+        ignition::fuel_tools::Result result = taskIt->get();
         if (result)
         {
           ++itemCount;
@@ -1047,8 +1078,6 @@ bool FuelClient::ParseModelUrl(const common::URI &_modelUrl,
   std::string modelName;
   std::string modelVersion;
 
-  std::regex_match(urlStr, match, *this->dataPtr->urlModelRegex);
-
   if (std::regex_match(urlStr, match, *this->dataPtr->urlModelRegex) &&
       match.size() >= 5u)
   {
@@ -1115,8 +1144,6 @@ bool FuelClient::ParseWorldUrl(const common::URI &_worldUrl,
   std::string worldName;
   std::string worldVersion;
 
-  std::regex_match(urlStr, match, *this->dataPtr->urlWorldRegex);
-
   if (std::regex_match(urlStr, match, *this->dataPtr->urlWorldRegex) &&
       match.size() >= 5u)
   {
@@ -1173,8 +1200,6 @@ bool FuelClient::ParseModelFileUrl(const common::URI &_fileUrl,
   if (!_fileUrl.Valid())
     return false;
 
-  this->dataPtr->CheckForDeprecatedUri(_fileUrl);
-
   auto urlStr = _fileUrl.Str();
 
   std::smatch match;
@@ -1398,7 +1423,7 @@ Result FuelClient::DownloadModel(const common::URI &_modelUrl,
     id.SetVersion(model.Identification().Version());
   }
 
-  _path = common::joinPaths(this->Config().CacheLocation(),
+  _path = ignition::common::joinPaths(this->Config().CacheLocation(),
       id.Server().Url().Path().Str(), id.Owner(), "models", id.Name(),
       id.VersionStr());
 
@@ -1518,10 +1543,10 @@ Result FuelClient::CachedModelFile(const common::URI &_fileUrl,
   // Check if file exists
   filePath = common::joinPaths(modelPath, filePath);
 
-  std::vector<std::string> tokens = common::split(filePath, "/");
+  std::vector<std::string> tokens = ignition::common::split(filePath, "/");
   std::string sTemp;
   for (auto s : tokens)
-    sTemp = common::joinPaths(sTemp, s);
+    sTemp = ignition::common::joinPaths(sTemp, s);
   filePath = sTemp;
 
   if (common::exists(filePath))
@@ -1568,7 +1593,7 @@ Result FuelClient::CachedWorldFile(const common::URI &_fileUrl,
 
 //////////////////////////////////////////////////
 Result FuelClient::PatchModel(
-    const ModelIdentifier &_model,
+    const ignition::fuel_tools::ModelIdentifier &_model,
     const std::vector<std::string> &_headers)
 {
   return this->PatchModel(_model, _headers, "");
@@ -1576,11 +1601,11 @@ Result FuelClient::PatchModel(
 
 //////////////////////////////////////////////////
 Result FuelClient::PatchModel(
-    const ModelIdentifier &_model,
+    const ignition::fuel_tools::ModelIdentifier &_model,
     const std::vector<std::string> &_headers,
     const std::string &_pathToModelDir)
 {
-  Rest rest;
+  ignition::fuel_tools::Rest rest;
   RestResponse resp;
 
   auto serverUrl = _model.Server().Url().Str();
@@ -1592,7 +1617,7 @@ Result FuelClient::PatchModel(
 
   if (!_pathToModelDir.empty() &&
       !this->dataPtr->FillModelForm(_pathToModelDir, _model,
-        _model.Private(), form))
+        _model.Private(), _model.Owner(), form))
   {
     return Result(ResultType::UPLOAD_ERROR);
   }
@@ -1638,7 +1663,7 @@ void FuelClient::PopulateLicenses(const ServerConfig &_server)
 
 //////////////////////////////////////////////////
 bool FuelClientPrivate::FillModelForm(const std::string &_pathToModelDir,
-    const ModelIdentifier &_id, bool _private,
+    const ModelIdentifier &_id, bool _private, const std::string &_owner,
     std::multimap<std::string, std::string> &_form)
 {
   if (!common::exists(_pathToModelDir))
@@ -1647,7 +1672,7 @@ bool FuelClientPrivate::FillModelForm(const std::string &_pathToModelDir,
     return false;
   }
 
-  msgs::FuelMetadata meta;
+  ignition::msgs::FuelMetadata meta;
 
   // Try the `metadata.pbtxt` file first since it contains more information
   // than `model.config`.
@@ -1675,7 +1700,7 @@ bool FuelClientPrivate::FillModelForm(const std::string &_pathToModelDir,
     std::string inputStr((std::istreambuf_iterator<char>(inputFile)),
         std::istreambuf_iterator<char>());
 
-    if (!msgs::ConvertFuelMetadata(inputStr, meta))
+    if (!ignition::msgs::ConvertFuelMetadata(inputStr, meta))
     {
       ignerr << "Unable to convert model config[" << _pathToModelDir << "].\n";
       return false;
@@ -1695,6 +1720,12 @@ bool FuelClientPrivate::FillModelForm(const std::string &_pathToModelDir,
     {"private", _private ? "1" : "0"},
   };
 
+  // Add owner if specified.
+  if (!_owner.empty())
+  {
+    _form.emplace("owner", _owner);
+  }
+
   // \todo(nkoenig) The ign-fuelserver expects an integer number for the
   // license information. The fuelserver should be modified to accept
   // a string. Otherwise, we have to bake into each client a mapping of
@@ -1757,7 +1788,6 @@ bool FuelClientPrivate::FillModelForm(const std::string &_pathToModelDir,
     _form.emplace("tags", tags);
 
   // Add categories
-  /* \todo: Uncomment in version 5.0
   std::string categories;
   if (meta.has_categories())
   {
@@ -1776,7 +1806,6 @@ bool FuelClientPrivate::FillModelForm(const std::string &_pathToModelDir,
   }
   if (!categories.empty())
     _form.emplace("categories", categories);
-  */
 
   // Add annotations as metadata.
   for (const auto &annotation : meta.annotations())
@@ -1818,78 +1847,83 @@ void FuelClientPrivate::PopulateLicenses(const ServerConfig &_server)
 }
 
 //////////////////////////////////////////////////
-void FuelClientPrivate::CheckForDeprecatedUri(const common::URI &_uri)
+bool FuelClient::UpdateModels(const std::vector<std::string> &_headers)
 {
-  static std::string oldServer = "fuel.ignitionrobotics.org";
-  auto ignFuelPos = _uri.Str().find(oldServer);
-  if (ignFuelPos != std::string::npos)
+  // Get a list of the most recent model versions in the cache.
+  std::map<std::string, ignition::fuel_tools::ModelIdentifier> toProcess;
+  for (ModelIter iter = this->dataPtr->cache->AllModels(); iter; ++iter)
   {
-    std::string newUrl = _uri.Str();
-    newUrl.replace(ignFuelPos, oldServer.size(), "fuel.gazebosim.org");
-    ignwarn << "The " << oldServer << " URL is deprecrated. Please change "
-      << _uri.Str() << " to " << newUrl << std::endl;
-  }
-}
-
-//////////////////////////////////////////////////
-void FuelClientPrivate::ZipFromResponse(const RestResponse &_resp,
-    std::string &_zip)
-{
-  // Check the content-type which could be empty (ideally not):
-  //   * text/plain indicates the data is a download link.
-  //   * application/zip indicates the data is a zip file.
-  //   * binary/octet-stream indicates the data is a zip file.
-  auto contentTypeIter = _resp.headers.find("Content-Type");
-  if (contentTypeIter != _resp.headers.end())
-  {
-    // If text/plain then data might be a link to a zip file.
-    if (contentTypeIter->second.find("text/plain") != std::string::npos)
+    auto processIter = toProcess.find(iter->Identification().UniqueName());
+    if (processIter == toProcess.end() ||
+        processIter->second.Version() < iter->Identification().Version())
     {
-      std::string linkUri = _resp.data;
-
-      // Check for valid URI
-      if (common::URI::Valid(linkUri))
-      {
-        igndbg << "Downloading from a referral link [" << linkUri << "]\n";
-        // Get the zip data.
-        RestResponse linkResp = rest.Request(HttpMethod::GET,
-            // URL
-            linkUri,
-            // Version
-            "",
-            // Path
-            "",
-            // Query strings
-            {},
-            // Headers
-            {},
-            // Data
-            "");
-
-        return this->ZipFromResponse(linkResp, _zip);
-      }
-      else
-      {
-        ignerr << "Invalid referral link URI [" << linkUri << "]. "
-          << "Unable to download.\n";
-      }
+      toProcess[iter->Identification().UniqueName()] = iter->Identification();
     }
-    else if (contentTypeIter->second.find("application/zip") !=
-             std::string::npos ||
-             contentTypeIter->second.find("binary/octet-stream") !=
-             std::string::npos)
+  }
+
+  // Attempt to update each model.
+  for (const auto id : toProcess)
+  {
+    ignition::fuel_tools::ModelIdentifier cloudId;
+
+    if (!this->ModelDetails(id.second, cloudId, _headers))
     {
-      _zip = std::move(_resp.data);
+      ignerr << "Failed to fetch model details for model["
+        << id.second.Owner()  << "/" << id.second.Name() << "]\n";
+    }
+    else if (id.second.Version() < cloudId.Version())
+    {
+      ignmsg << "Updating model " << id.second.Owner() << "/"
+        << id.second.Name() << " up to version "
+        << cloudId.Version() << std::endl;
+      this->DownloadModel(cloudId, _headers);
     }
     else
     {
-      ignerr << "Invalid content-type of [" << contentTypeIter->second << "]. "
-        << "Unable to download.\n";
+      ignmsg << "Model " << id.second.Owner() << "/"
+        << id.second.Name() << " is up to date." << std::endl;
     }
   }
-  else
+  return true;
+}
+
+//////////////////////////////////////////////////
+bool FuelClient::UpdateWorlds(const std::vector<std::string> &_headers)
+{
+  // Get a list of the most recent world versions in the cache.
+  std::map<std::string, ignition::fuel_tools::WorldIdentifier> toProcess;
+  for (WorldIter iter = this->dataPtr->cache->AllWorlds(); iter; ++iter)
   {
-    // If content-type is missing, then assume the data is the zip file.
-    _zip = std::move(_resp.data);
+    auto processIter = toProcess.find(iter->UniqueName());
+    if (processIter == toProcess.end() ||
+        processIter->second.Version() < iter->Version())
+    {
+      toProcess[iter->UniqueName()] = *iter;
+    }
   }
+
+  // Attempt to update each world.
+  for (const auto id : toProcess)
+  {
+    ignition::fuel_tools::WorldIdentifier cloudId;
+
+    if (!this->WorldDetails(id.second, cloudId, _headers))
+    {
+      ignerr << "Failed to fetch world details for world["
+        << id.second.Owner() << "/" << id.second.Name() << "]\n";
+    }
+    else if (id.second.Version() < cloudId.Version())
+    {
+      ignmsg << "Updating world " << id.second.Owner() << "/"
+        << id.second.Name() << " up to version "
+        << cloudId.Version() << std::endl;
+      this->DownloadWorld(cloudId, _headers);
+    }
+    else
+    {
+      ignmsg << "World " << id.second.Owner() << "/"
+        << id.second.Name() << " is up to date." << std::endl;
+    }
+  }
+  return true;
 }
