@@ -17,14 +17,14 @@
 
 #include <gtest/gtest.h>
 #include <fstream>
-#include <gz/common/Console.hh>
-#include <gz/common/Filesystem.hh>
-#include <gz/utilities/ExtraTestMacros.hh>
+#include <ignition/common/Console.hh>
+#include <ignition/common/Filesystem.hh>
+#include <ignition/utilities/ExtraTestMacros.hh>
 
-#include "gz/fuel_tools/FuelClient.hh"
-#include "gz/fuel_tools/ClientConfig.hh"
-#include "gz/fuel_tools/Result.hh"
-#include "gz/fuel_tools/WorldIdentifier.hh"
+#include "ignition/fuel_tools/FuelClient.hh"
+#include "ignition/fuel_tools/ClientConfig.hh"
+#include "ignition/fuel_tools/Result.hh"
+#include "ignition/fuel_tools/WorldIdentifier.hh"
 
 #include "test/test_config.h"
 
@@ -89,7 +89,7 @@ void createLocalModel(ClientConfig &_conf)
         "model.dae")));
   }
 
-  ServerConfig srv;
+  ignition::fuel_tools::ServerConfig srv;
   srv.SetUrl(common::URI("http://localhost:8007/"));
   _conf.AddServer(srv);
 }
@@ -120,8 +120,8 @@ void createLocalWorld(ClientConfig &_conf)
         "strawberry.world")));
   }
 
-  ServerConfig srv;
-  srv.SetUrl(common::URI("http://localhost:8007/"));
+  ignition::fuel_tools::ServerConfig srv;
+  srv.SetUrl(ignition::common::URI("http://localhost:8007/"));
   _conf.AddServer(srv);
 }
 
@@ -130,7 +130,7 @@ class FuelClientTest : public ::testing::Test
 {
   public: void SetUp() override
   {
-    common::Console::SetVerbosity(4);
+    ignition::common::Console::SetVerbosity(4);
   }
 };
 
@@ -145,12 +145,12 @@ TEST_F(FuelClientTest, ParseModelURL)
     FuelClient client;
     ModelIdentifier id;
     const std::string url{
-      "https://some.example.org/1.0/openroboticstest/models/Cardboard Box"};
-    EXPECT_TRUE(client.ParseModelUrl(common::URI(url), id));
+      "https://some.example.org/1.0/german/models/Cardboard Box"};
+    EXPECT_TRUE(client.ParseModelUrl(ignition::common::URI(url), id));
 
     EXPECT_EQ(id.Server().Url().Str(), "https://some.example.org");
     EXPECT_EQ(id.Server().Version(), "1.0");
-    EXPECT_EQ(id.Owner(), "openroboticstest");
+    EXPECT_EQ(id.Owner(), "german");
     EXPECT_EQ(id.Name(), "cardboard box");
     EXPECT_EQ(id.Version(), 0u);
   }
@@ -164,12 +164,12 @@ TEST_F(FuelClientTest, ParseModelURL)
     FuelClient client(config);
     ModelIdentifier id;
     const std::string url{
-      "https://fuel.gazebosim.org/1.0/openroboticstest/models/Cardboard Box/4"};
-    EXPECT_TRUE(client.ParseModelUrl(common::URI(url), id));
+      "https://fuel.ignitionrobotics.org/1.0/german/models/Cardboard Box/4"};
+    EXPECT_TRUE(client.ParseModelUrl(ignition::common::URI(url), id));
 
-    EXPECT_EQ(id.Server().Url().Str(), "https://fuel.gazebosim.org");
+    EXPECT_EQ(id.Server().Url().Str(), "https://fuel.ignitionrobotics.org");
     EXPECT_EQ(id.Server().Version(), "1.0");
-    EXPECT_EQ(id.Owner(), "openroboticstest");
+    EXPECT_EQ(id.Owner(), "german");
     EXPECT_EQ(id.Name(), "cardboard box");
     EXPECT_EQ(id.Version(), 4u);
   }
@@ -177,19 +177,19 @@ TEST_F(FuelClientTest, ParseModelURL)
   // * with client config
   // * with server API version different from config
   // * with model version
+  // * with trailing /
   {
     ClientConfig config;
 
     FuelClient client(config);
     ModelIdentifier id;
     const std::string url{
-      "https://fuel.gazebosim.org/5.0/openroboticstest/models/Cardboard Box/6/"
-    };
-    EXPECT_TRUE(client.ParseModelUrl(common::URI(url), id));
+      "https://fuel.ignitionrobotics.org/5.0/german/models/Cardboard Box/6/"};
+    EXPECT_TRUE(client.ParseModelUrl(ignition::common::URI(url), id));
 
-    EXPECT_EQ(id.Server().Url().Str(), "https://fuel.gazebosim.org");
+    EXPECT_EQ(id.Server().Url().Str(), "https://fuel.ignitionrobotics.org");
     EXPECT_EQ(id.Server().Version(), "1.0");
-    EXPECT_EQ(id.Owner(), "openroboticstest");
+    EXPECT_EQ(id.Owner(), "german");
     EXPECT_EQ(id.Name(), "cardboard box");
     EXPECT_EQ(id.Version(), 6u);
   }
@@ -201,12 +201,12 @@ TEST_F(FuelClientTest, ParseModelURL)
     FuelClient client;
     ModelIdentifier id;
     const std::string url{
-      "https://fuel.gazebosim.org/openroboticstest/models/Cardboard Box"};
-    EXPECT_TRUE(client.ParseModelUrl(common::URI(url), id));
+      "https://fuel.ignitionrobotics.org/german/models/Cardboard Box"};
+    EXPECT_TRUE(client.ParseModelUrl(ignition::common::URI(url), id));
 
-    EXPECT_EQ(id.Server().Url().Str(), "https://fuel.gazebosim.org");
+    EXPECT_EQ(id.Server().Url().Str(), "https://fuel.ignitionrobotics.org");
     EXPECT_FALSE(id.Server().Version().empty());
-    EXPECT_EQ(id.Owner(), "openroboticstest");
+    EXPECT_EQ(id.Owner(), "german");
     EXPECT_EQ(id.Name(), "cardboard box");
     EXPECT_EQ(id.Version(), 0u);
   }
@@ -220,12 +220,12 @@ TEST_F(FuelClientTest, ParseModelURL)
     FuelClient client(config);
     ModelIdentifier id;
     const std::string url{
-      "https://fuel.gazebosim.org/openroboticstest/models/Cardboard Box/tip"};
-    EXPECT_TRUE(client.ParseModelUrl(common::URI(url), id));
+      "https://fuel.ignitionrobotics.org/german/models/Cardboard Box/tip"};
+    EXPECT_TRUE(client.ParseModelUrl(ignition::common::URI(url), id));
 
-    EXPECT_EQ(id.Server().Url().Str(), "https://fuel.gazebosim.org");
+    EXPECT_EQ(id.Server().Url().Str(), "https://fuel.ignitionrobotics.org");
     EXPECT_EQ(id.Server().Version(), "1.0");
-    EXPECT_EQ(id.Owner(), "openroboticstest");
+    EXPECT_EQ(id.Owner(), "german");
     EXPECT_EQ(id.Name(), "cardboard box");
     EXPECT_EQ(id.Version(), 0u);
   }
@@ -234,7 +234,7 @@ TEST_F(FuelClientTest, ParseModelURL)
   {
     FuelClient client;
     ModelIdentifier id;
-    EXPECT_FALSE(client.ParseModelUrl(common::URI("http://bad.url"),
+    EXPECT_FALSE(client.ParseModelUrl(ignition::common::URI("http://bad.url"),
           id));
   }
 
@@ -242,45 +242,43 @@ TEST_F(FuelClientTest, ParseModelURL)
   {
     FuelClient client;
     ModelIdentifier id;
-    EXPECT_FALSE(client.ParseModelUrl(common::URI("bad url"),
+    EXPECT_FALSE(client.ParseModelUrl(ignition::common::URI("bad url"),
           id));
   }
   {
     FuelClient client;
     ModelIdentifier id;
-    EXPECT_FALSE(client.ParseModelUrl(common::URI("ba://url"),
+    EXPECT_FALSE(client.ParseModelUrl(ignition::common::URI("ba://url"),
           id));
   }
   {
     FuelClient client;
     ModelIdentifier id;
     const std::string url{
-      "https://fuel.gazebosim.org/openroboticstest/models/Cardboard Box/banana"
-    };
-    EXPECT_FALSE(client.ParseModelUrl(common::URI(url), id));
+      "https://fuel.ignitionrobotics.org/german/models/Cardboard Box/banana"};
+    EXPECT_FALSE(client.ParseModelUrl(ignition::common::URI(url), id));
   }
   {
     FuelClient client;
     ModelIdentifier id;
     const std::string url{
-      "https://fuel.gazebosim.org/banana/openroboticstest/models/Cardboard Box"
-    };
-    EXPECT_FALSE(client.ParseModelUrl(common::URI(url), id));
+      "https://fuel.ignitionrobotics.org/banana/german/models/Cardboard Box"};
+    EXPECT_FALSE(client.ParseModelUrl(ignition::common::URI(url), id));
   }
   {
     FuelClient client;
     ModelIdentifier id;
     const std::string url{
-      "https://fuel.gazebosim.org/99/openroboticstest/models/Cardboard Box"};
-    EXPECT_FALSE(client.ParseModelUrl(common::URI(url), id));
+      "https://fuel.ignitionrobotics.org/99/german/models/Cardboard Box"};
+    EXPECT_FALSE(client.ParseModelUrl(ignition::common::URI(url), id));
   }
   {
     FuelClient client;
     ModelIdentifier id;
     const std::string url{
-      "https://fuel.gazebosim.org/2/2/openroboticstest/models"
+      "https://fuel.ignitionrobotics.org/2/2/german/models"
         "/Cardboard Box/banana"};
-    EXPECT_FALSE(client.ParseModelUrl(common::URI(url), id));
+    EXPECT_FALSE(client.ParseModelUrl(ignition::common::URI(url), id));
   }
 }
 
@@ -293,15 +291,15 @@ TEST_F(FuelClientTest, ParseModelFileURL)
     ModelIdentifier id;
     std::string filePath;
     const common::URI modelUrl{
-      "https://fuel.gazebosim.org/1.0/openroboticstest/models/"
-        "backpack/tip/files/model.sdf"};
+      "https://fuel.ignitionrobotics.org/1.0/OpenRobotics/models/"
+        "Cordless Drill/tip/files/meshes/cordless_drill.dae"};
     EXPECT_TRUE(client.ParseModelFileUrl(modelUrl, id, filePath));
 
-    EXPECT_EQ(id.Server().Url().Str(), "https://fuel.gazebosim.org");
+    EXPECT_EQ(id.Server().Url().Str(), "https://fuel.ignitionrobotics.org");
     EXPECT_EQ(id.Server().Version(), "1.0");
-    EXPECT_EQ(id.Owner(), "openroboticstest");
-    EXPECT_EQ(id.Name(), "backpack");
-    EXPECT_EQ(filePath, "model.sdf");
+    EXPECT_EQ(id.Owner(), "openrobotics");
+    EXPECT_EQ(id.Name(), "cordless drill");
+    EXPECT_EQ(filePath, "meshes/cordless_drill.dae");
   }
 
   // URL - with client config
@@ -312,15 +310,15 @@ TEST_F(FuelClientTest, ParseModelFileURL)
     ModelIdentifier id;
     std::string filePath;
     const common::URI modelUrl{
-      "https://fuel.gazebosim.org/1.0/openroboticstest/models/backpack/"
-        "tip/files/model.sdf"};
+      "https://fuel.ignitionrobotics.org/1.0/openrobotics/models/Pine Tree/tip/"
+      "files/materials/scripts/pine_tree.material"};
     EXPECT_TRUE(client.ParseModelFileUrl(modelUrl, id, filePath));
 
-    EXPECT_EQ(id.Server().Url().Str(), "https://fuel.gazebosim.org");
+    EXPECT_EQ(id.Server().Url().Str(), "https://fuel.ignitionrobotics.org");
     EXPECT_EQ(id.Server().Version(), "1.0");
-    EXPECT_EQ(id.Owner(), "openroboticstest");
-    EXPECT_EQ(id.Name(), "backpack");
-    EXPECT_EQ(filePath, "model.sdf");
+    EXPECT_EQ(id.Owner(), "openrobotics");
+    EXPECT_EQ(id.Name(), "pine tree");
+    EXPECT_EQ(filePath, "materials/scripts/pine_tree.material");
   }
 
   // URL - version different from config
@@ -331,14 +329,14 @@ TEST_F(FuelClientTest, ParseModelFileURL)
     ModelIdentifier id;
     std::string filePath;
     const common::URI modelUrl{
-      "https://fuel.gazebosim.org/5.0/openroboticstest/models/backpack/"
-        "tip/files/model.sdf"};
+      "https://fuel.ignitionrobotics.org/5.0/OpenRobotics/models/Pine Tree/tip/"
+      "files/model.sdf"};
     EXPECT_TRUE(client.ParseModelFileUrl(modelUrl, id, filePath));
 
-    EXPECT_EQ(id.Server().Url().Str(), "https://fuel.gazebosim.org");
+    EXPECT_EQ(id.Server().Url().Str(), "https://fuel.ignitionrobotics.org");
     EXPECT_EQ(id.Server().Version(), "1.0");
-    EXPECT_EQ(id.Owner(), "openroboticstest");
-    EXPECT_EQ(id.Name(), "backpack");
+    EXPECT_EQ(id.Owner(), "openrobotics");
+    EXPECT_EQ(id.Name(), "pine tree");
     EXPECT_EQ(filePath, "model.sdf");
   }
 
@@ -348,16 +346,16 @@ TEST_F(FuelClientTest, ParseModelFileURL)
     ModelIdentifier id;
     std::string filePath;
     const common::URI modelUrl{
-      "https://fuel.gazebosim.org/openroboticstest/models/backpack/tip/"
-      "files/model.sdf"};
+      "https://fuel.ignitionrobotics.org/OpenRobotics/models/pine tree/tip/"
+      "files/materials/scripts/pine_tree.material"};
     EXPECT_TRUE(client.ParseModelFileUrl(modelUrl, id, filePath));
 
-    EXPECT_EQ(id.Server().Url().Str(), "https://fuel.gazebosim.org");
+    EXPECT_EQ(id.Server().Url().Str(), "https://fuel.ignitionrobotics.org");
     EXPECT_FALSE(id.Server().Version().empty());
     EXPECT_EQ("1.0", id.Server().Version());
-    EXPECT_EQ(id.Owner(), "openroboticstest");
-    EXPECT_EQ(id.Name(), "backpack");
-    EXPECT_EQ(filePath, "model.sdf");
+    EXPECT_EQ(id.Owner(), "openrobotics");
+    EXPECT_EQ(id.Name(), "pine tree");
+    EXPECT_EQ(filePath, "materials/scripts/pine_tree.material");
   }
 
   // Unique name - with client config
@@ -368,15 +366,15 @@ TEST_F(FuelClientTest, ParseModelFileURL)
     ModelIdentifier id;
     std::string filePath;
     const common::URI modelUrl{
-      "https://fuel.gazebosim.org/openroboticstest/models/backpack/tip/"
-      "files/model.sdf"};
+      "https://fuel.ignitionrobotics.org/openrobotics/models/Pine Tree/tip/"
+      "files/materials/scripts/pine_tree.material"};
     EXPECT_TRUE(client.ParseModelFileUrl(modelUrl, id, filePath));
 
-    EXPECT_EQ(id.Server().Url().Str(), "https://fuel.gazebosim.org");
+    EXPECT_EQ(id.Server().Url().Str(), "https://fuel.ignitionrobotics.org");
     EXPECT_EQ(id.Server().Version(), "1.0");
-    EXPECT_EQ(id.Owner(), "openroboticstest");
-    EXPECT_EQ(id.Name(), "backpack");
-    EXPECT_EQ(filePath, "model.sdf");
+    EXPECT_EQ(id.Owner(), "openrobotics");
+    EXPECT_EQ(id.Name(), "pine tree");
+    EXPECT_EQ(filePath, "materials/scripts/pine_tree.material");
   }
 
   // Bad URL
@@ -398,20 +396,10 @@ TEST_F(FuelClientTest, ParseModelFileURL)
   }
 }
 
-class FuelClientDownloadTest
-    : public FuelClientTest,
-      public ::testing::WithParamInterface<const char *>
-{};
-
-INSTANTIATE_TEST_CASE_P(
-    FuelClientTest, FuelClientDownloadTest,
-    ::testing::Values("fuel.gazebosim.org",
-                      "fuel.ignitionrobotics.org"), );  // NOLINT
-
 /////////////////////////////////////////////////
 // Protocol "https" not supported or disabled in libcurl for Windows
-// https://github.com/gazebosim/gz-fuel-tools/issues/105
-TEST_P(FuelClientDownloadTest, DownloadModel)
+// https://github.com/ignitionrobotics/ign-fuel-tools/issues/105
+TEST_F(FuelClientTest, DownloadModel)
 {
   // Configure to use binary path as cache
   ASSERT_EQ(0, ChangeDirectory(PROJECT_BINARY_PATH));
@@ -424,12 +412,11 @@ TEST_P(FuelClientDownloadTest, DownloadModel)
   FuelClient client(config);
   EXPECT_EQ(config.CacheLocation(), client.Config().CacheLocation());
 
-  std::string fuelServerHost = GetParam();
   // Download model from URL
   {
     // Unversioned URL should get the latest available version
     common::URI url{
-      "https://" + fuelServerHost + "/1.0/openroboticstest/models/test box"};
+        "https://fuel.ignitionrobotics.org/1.0/chapulina/models/Test box"};
 
     // Check it is not cached
     std::string cachedPath;
@@ -445,12 +432,12 @@ TEST_P(FuelClientDownloadTest, DownloadModel)
 
     // Check it was downloaded to `2`
     auto modelPath = common::joinPaths(common::cwd(), "test_cache",
-        fuelServerHost, "openroboticstest", "models", "test box");
+        "fuel.ignitionrobotics.org", "chapulina", "models", "test box");
 
-    EXPECT_EQ(path, common::joinPaths(modelPath, "1"));
-    EXPECT_TRUE(common::exists(common::joinPaths(modelPath, "1")));
-    EXPECT_TRUE(common::exists(common::joinPaths(modelPath, "1", "model.sdf")));
-    EXPECT_TRUE(common::exists(common::joinPaths(modelPath, "1",
+    EXPECT_EQ(path, common::joinPaths(modelPath, "2"));
+    EXPECT_TRUE(common::exists(common::joinPaths(modelPath, "2")));
+    EXPECT_TRUE(common::exists(common::joinPaths(modelPath, "2", "model.sdf")));
+    EXPECT_TRUE(common::exists(common::joinPaths(modelPath, "2",
         "model.config")));
 
     // Check it wasn't downloaded to model root directory
@@ -460,14 +447,14 @@ TEST_P(FuelClientDownloadTest, DownloadModel)
     Result res3 = client.CachedModel(url, cachedPath);
     EXPECT_TRUE(res3);
     EXPECT_EQ(ResultType::FETCH_ALREADY_EXISTS, res3.Type());
-    EXPECT_EQ(common::joinPaths(modelPath, "1"), cachedPath);
+    EXPECT_EQ(common::joinPaths(modelPath, "2"), cachedPath);
   }
 
   // Download model with pbr paths from URL and check that paths are fixed
   {
     // Unversioned URL should get the latest available version
-    common::URI url{"https://" + fuelServerHost +
-                    "/1.0/openroboticstest/models/Rescue Randy"};
+    common::URI url{
+        "https://fuel.ignitionrobotics.org/1.0/iche033/models/Rescue Randy"};
 
     // Check it is not cached
     std::string cachedPath;
@@ -483,7 +470,7 @@ TEST_P(FuelClientDownloadTest, DownloadModel)
 
     // Check it was downloaded to `2`
     auto modelPath = common::joinPaths(common::cwd(), "test_cache",
-        fuelServerHost, "openroboticstest", "models", "rescue randy");
+        "fuel.ignitionrobotics.org", "iche033", "models", "rescue randy");
 
     EXPECT_EQ(path, common::joinPaths(modelPath, "2"));
     EXPECT_TRUE(common::exists(common::joinPaths(modelPath, "2")));
@@ -519,13 +506,10 @@ TEST_P(FuelClientDownloadTest, DownloadModel)
 
   // Download model with a dependency specified within its `metadata.pbtxt`
   {
-    common::URI url{"https://" + fuelServerHost +
-                    "/1.0/openroboticstest/models/hatchback_red_1"};
-
-    // The dependency will use the fuel.gazebosim.org URI regardless of what
-    // fuelServerHost is because it's set in the hatchback_red_1 model
+    common::URI url{
+        "https://fuel.ignitionrobotics.org/1.0/JShep1/models/hatchback_red_1"};
     common::URI depUrl{
-        "https://fuel.gazebosim.org/1.0/openroboticstest/models/hatchback_1"};
+        "https://fuel.ignitionrobotics.org/1.0/JShep1/models/hatchback_1"};
 
     // Check it is not cached
     std::string cachedPath;
@@ -555,16 +539,12 @@ TEST_P(FuelClientDownloadTest, DownloadModel)
     EXPECT_EQ(ResultType::FETCH_ALREADY_EXISTS, res5.Type());
   }
 
-  // Download model with a dependency specified within its `model.config`.
-  // The dependency points to fuel.gazebosim.org.
+  // Download model with a dependency specified within its `model.config`
   {
     common::URI url{
-      "https://" + fuelServerHost + "/1.0/openrobotics/models/hatchback red"
-    };
-    // The dependency will use the fuel.gazebosim.org URI regardless of what
-    // fuelServerHost is because it's set in the "hatchback red" model
+        "https://fuel.ignitionrobotics.org/1.0/JShep1/models/hatchback_red_2"};
     common::URI depUrl{
-      "https://fuel.gazebosim.org/1.0/openrobotics/models/hatchback"};
+        "https://fuel.ignitionrobotics.org/1.0/JShep1/models/hatchback_2"};
 
     // Check it is not cached
     std::string cachedPath;
@@ -597,7 +577,7 @@ TEST_P(FuelClientDownloadTest, DownloadModel)
   // Try using nonexistent URL
   {
     std::string url{
-        "https://" + fuelServerHost + "/1.0/openroboticstest/models/"
+        "https://fuel.ignitionrobotics.org/1.0/chapulina/models/"
           "Inexistent model"};
     std::string path;
     Result result = client.DownloadModel(common::URI(url), path);
@@ -617,7 +597,7 @@ TEST_P(FuelClientDownloadTest, DownloadModel)
 
 /////////////////////////////////////////////////
 // Windows doesn't support colons in filenames
-// https://github.com/gazebosim/gz-fuel-tools/issues/106
+// https://github.com/ignitionrobotics/ign-fuel-tools/issues/106
 TEST_F(FuelClientTest, IGN_UTILS_TEST_DISABLED_ON_WIN32(ModelDependencies))
 {
   // Configure to use binary path as cache
@@ -634,10 +614,9 @@ TEST_F(FuelClientTest, IGN_UTILS_TEST_DISABLED_ON_WIN32(ModelDependencies))
   // Download model with a dependency specified within its `metadata.pbtxt`
   {
     common::URI url{
-        "https://fuel.gazebosim.org/1.0/openroboticstest/models/hatchback_red_1"
-    };
+        "https://fuel.ignitionrobotics.org/1.0/JShep1/models/hatchback_red_1"};
     common::URI depUrl{
-        "https://fuel.gazebosim.org/1.0/openroboticstest/models/hatchback_1"};
+        "https://fuel.ignitionrobotics.org/1.0/JShep1/models/hatchback_1"};
 
     ModelIdentifier id;
     ModelIdentifier depId;
@@ -692,7 +671,7 @@ TEST_F(FuelClientTest, IGN_UTILS_TEST_DISABLED_ON_WIN32(ModelDependencies))
 
 /////////////////////////////////////////////////
 // Windows doesn't support colons in filenames
-// https://github.com/gazebosim/gz-fuel-tools/issues/106
+// https://github.com/ignitionrobotics/ign-fuel-tools/issues/106
 TEST_F(FuelClientTest, CachedModel)
 {
   // Configure to use binary path as cache and populate it
@@ -832,12 +811,12 @@ TEST_F(FuelClientTest, ParseWorldUrl)
     FuelClient client;
     WorldIdentifier id;
     const common::URI url{
-      "https://fuel.gazebosim.org/1.0/openroboticstest/worlds/Cardboard Box"};
+      "https://fuel.ignitionrobotics.org/1.0/german/worlds/Cardboard Box"};
     EXPECT_TRUE(client.ParseWorldUrl(url, id));
 
-    EXPECT_EQ(id.Server().Url().Str(), "https://fuel.gazebosim.org");
+    EXPECT_EQ(id.Server().Url().Str(), "https://fuel.ignitionrobotics.org");
     EXPECT_EQ(id.Server().Version(), "1.0");
-    EXPECT_EQ(id.Owner(), "openroboticstest");
+    EXPECT_EQ(id.Owner(), "german");
     EXPECT_EQ(id.Name(), "cardboard box");
     EXPECT_EQ(id.Version(), 0u);
   }
@@ -851,12 +830,12 @@ TEST_F(FuelClientTest, ParseWorldUrl)
     FuelClient client(config);
     WorldIdentifier id;
     const common::URI url{
-      "https://fuel.gazebosim.org/1.0/openroboticstest/worlds/Cardboard Box/4"};
+      "https://fuel.ignitionrobotics.org/1.0/german/worlds/Cardboard Box/4"};
     EXPECT_TRUE(client.ParseWorldUrl(url, id));
 
-    EXPECT_EQ(id.Server().Url().Str(), "https://fuel.gazebosim.org");
+    EXPECT_EQ(id.Server().Url().Str(), "https://fuel.ignitionrobotics.org");
     EXPECT_EQ(id.Server().Version(), "1.0");
-    EXPECT_EQ(id.Owner(), "openroboticstest");
+    EXPECT_EQ(id.Owner(), "german");
     EXPECT_EQ(id.Name(), "cardboard box");
     EXPECT_EQ(id.Version(), 4u);
   }
@@ -870,12 +849,12 @@ TEST_F(FuelClientTest, ParseWorldUrl)
     FuelClient client(config);
     WorldIdentifier id;
     const common::URI url{
-      "https://fuel.gazebosim.org/5.0/openroboticstest/worlds/Cardboard Box/6"};
+      "https://fuel.ignitionrobotics.org/5.0/german/worlds/Cardboard Box/6"};
     EXPECT_TRUE(client.ParseWorldUrl(url, id));
 
-    EXPECT_EQ(id.Server().Url().Str(), "https://fuel.gazebosim.org");
+    EXPECT_EQ(id.Server().Url().Str(), "https://fuel.ignitionrobotics.org");
     EXPECT_EQ(id.Server().Version(), "1.0");
-    EXPECT_EQ(id.Owner(), "openroboticstest");
+    EXPECT_EQ(id.Owner(), "german");
     EXPECT_EQ(id.Name(), "cardboard box");
     EXPECT_EQ(id.Version(), 6u);
   }
@@ -887,13 +866,13 @@ TEST_F(FuelClientTest, ParseWorldUrl)
     FuelClient client;
     WorldIdentifier id;
     const common::URI url{
-      "https://fuel.gazebosim.org/openroboticstest/worlds/Cardboard Box"};
+      "https://fuel.ignitionrobotics.org/german/worlds/Cardboard Box"};
     EXPECT_TRUE(client.ParseWorldUrl(url, id));
 
-    EXPECT_EQ(id.Server().Url().Str(), "https://fuel.gazebosim.org");
+    EXPECT_EQ(id.Server().Url().Str(), "https://fuel.ignitionrobotics.org");
     EXPECT_FALSE(id.Server().Version().empty());
     EXPECT_EQ("1.0", id.Server().Version());
-    EXPECT_EQ(id.Owner(), "openroboticstest");
+    EXPECT_EQ(id.Owner(), "german");
     EXPECT_EQ(id.Name(), "cardboard box");
     EXPECT_EQ(id.Version(), 0u);
   }
@@ -908,12 +887,12 @@ TEST_F(FuelClientTest, ParseWorldUrl)
     FuelClient client(config);
     WorldIdentifier id;
     const common::URI url{
-      "https://fuel.gazebosim.org/openroboticstest/worlds/Cardboard Box/tip/"};
+      "https://fuel.ignitionrobotics.org/german/worlds/Cardboard Box/tip/"};
     EXPECT_TRUE(client.ParseWorldUrl(url, id));
 
-    EXPECT_EQ(id.Server().Url().Str(), "https://fuel.gazebosim.org");
+    EXPECT_EQ(id.Server().Url().Str(), "https://fuel.ignitionrobotics.org");
     EXPECT_EQ(id.Server().Version(), "1.0");
-    EXPECT_EQ(id.Owner(), "openroboticstest");
+    EXPECT_EQ(id.Owner(), "german");
     EXPECT_EQ(id.Name(), "cardboard box");
     EXPECT_EQ(id.Version(), 0u);
   }
@@ -940,29 +919,28 @@ TEST_F(FuelClientTest, ParseWorldUrl)
     FuelClient client;
     WorldIdentifier id;
     const common::URI url{
-      "https://fuel.gazebosim.org/openroboticstest/worlds/Cardboard Box/here"};
+      "https://fuel.ignitionrobotics.org/german/worlds/Cardboard Box/banana"};
     EXPECT_FALSE(client.ParseWorldUrl(url, id));
   }
   {
     FuelClient client;
     WorldIdentifier id;
     const common::URI url{
-      "https://fuel.gazebosim.org/banana/openroboticstest/worlds/Cardboard Box"
-    };
+      "https://fuel.ignitionrobotics.org/banana/german/worlds/Cardboard Box"};
     EXPECT_FALSE(client.ParseWorldUrl(url, id));
   }
   {
     FuelClient client;
     WorldIdentifier id;
     const common::URI url{
-      "https://fuel.gazebosim.org/99/openroboticstest/worlds/Cardboard Box"};
+      "https://fuel.ignitionrobotics.org/99/german/worlds/Cardboard Box"};
     EXPECT_FALSE(client.ParseWorldUrl(url, id));
   }
   {
     FuelClient client;
     WorldIdentifier id;
     const common::URI url{
-      "https://fuel.gazebosim.org/2/2/openroboticstest/worlds/Cardboard Box"
+      "https://fuel.ignitionrobotics.org/2/2/german/worlds/Cardboard Box"
         "/banana"};
     EXPECT_FALSE(client.ParseWorldUrl(url, id));
   }
@@ -977,11 +955,11 @@ TEST_F(FuelClientTest, ParseWorldFileUrl)
     WorldIdentifier id;
     std::string filePath;
     const common::URI worldUrl{
-      "https://fuel.gazebosim.org/1.0/OpenRobotics/worlds/Empty/tip/"
+      "https://fuel.ignitionrobotics.org/1.0/OpenRobotics/worlds/Empty/tip/"
       "files/test.world"};
     EXPECT_TRUE(client.ParseWorldFileUrl(worldUrl, id, filePath));
 
-    EXPECT_EQ(id.Server().Url().Str(), "https://fuel.gazebosim.org");
+    EXPECT_EQ(id.Server().Url().Str(), "https://fuel.ignitionrobotics.org");
     EXPECT_EQ(id.Server().Version(), "1.0");
     EXPECT_EQ(id.Owner(), "openrobotics");
     EXPECT_EQ(id.Name(), "empty");
@@ -996,11 +974,11 @@ TEST_F(FuelClientTest, ParseWorldFileUrl)
     WorldIdentifier id;
     std::string filePath;
     const common::URI worldUrl{
-      "https://fuel.gazebosim.org/1.0/OpenRobotics/worlds/Empty sky/tip/"
+      "https://fuel.ignitionrobotics.org/1.0/OpenRobotics/worlds/Empty sky/tip/"
       "files/empty_sky.world"};
     EXPECT_TRUE(client.ParseWorldFileUrl(worldUrl, id, filePath));
 
-    EXPECT_EQ(id.Server().Url().Str(), "https://fuel.gazebosim.org");
+    EXPECT_EQ(id.Server().Url().Str(), "https://fuel.ignitionrobotics.org");
     EXPECT_EQ(id.Server().Version(), "1.0");
     EXPECT_EQ(id.Owner(), "openrobotics");
     EXPECT_EQ(id.Name(), "empty sky");
@@ -1015,11 +993,11 @@ TEST_F(FuelClientTest, ParseWorldFileUrl)
     WorldIdentifier id;
     std::string filePath;
     const common::URI worldUrl{
-      "https://fuel.gazebosim.org/5.0/OpenRobotics/worlds/Empty/tip/"
+      "https://fuel.ignitionrobotics.org/5.0/OpenRobotics/worlds/Empty/tip/"
       "files/test.world"};
     EXPECT_TRUE(client.ParseWorldFileUrl(worldUrl, id, filePath));
 
-    EXPECT_EQ(id.Server().Url().Str(), "https://fuel.gazebosim.org");
+    EXPECT_EQ(id.Server().Url().Str(), "https://fuel.ignitionrobotics.org");
     EXPECT_EQ(id.Server().Version(), "1.0");
     EXPECT_EQ(id.Owner(), "openrobotics");
     EXPECT_EQ(id.Name(), "empty");
@@ -1032,11 +1010,11 @@ TEST_F(FuelClientTest, ParseWorldFileUrl)
     WorldIdentifier id;
     std::string filePath;
     const common::URI worldUrl{
-      "https://fuel.gazebosim.org/OpenRobotics/worlds/Empty sky/tip/"
+      "https://fuel.ignitionrobotics.org/OpenRobotics/worlds/Empty sky/tip/"
       "files/empty_sky.world"};
     EXPECT_TRUE(client.ParseWorldFileUrl(worldUrl, id, filePath));
 
-    EXPECT_EQ(id.Server().Url().Str(), "https://fuel.gazebosim.org");
+    EXPECT_EQ(id.Server().Url().Str(), "https://fuel.ignitionrobotics.org");
     EXPECT_FALSE(id.Server().Version().empty());
     EXPECT_EQ("1.0", id.Server().Version());
     EXPECT_EQ(id.Owner(), "openrobotics");
@@ -1052,11 +1030,11 @@ TEST_F(FuelClientTest, ParseWorldFileUrl)
     WorldIdentifier id;
     std::string filePath;
     const common::URI worldUrl{
-      "https://fuel.gazebosim.org/1.0/OpenRobotics/worlds/Empty/tip/"
+      "https://fuel.ignitionrobotics.org/1.0/OpenRobotics/worlds/Empty/tip/"
       "files/test.world"};
     EXPECT_TRUE(client.ParseWorldFileUrl(worldUrl, id, filePath));
 
-    EXPECT_EQ(id.Server().Url().Str(), "https://fuel.gazebosim.org");
+    EXPECT_EQ(id.Server().Url().Str(), "https://fuel.ignitionrobotics.org");
     EXPECT_EQ(id.Server().Version(), "1.0");
     EXPECT_EQ(id.Owner(), "openrobotics");
     EXPECT_EQ(id.Name(), "empty");
@@ -1084,7 +1062,7 @@ TEST_F(FuelClientTest, ParseWorldFileUrl)
 
 //////////////////////////////////////////////////
 // Protocol "https" not supported or disabled in libcurl for Windows
-// https://github.com/gazebosim/gz-fuel-tools/issues/105
+// https://github.com/ignitionrobotics/ign-fuel-tools/issues/105
 TEST_F(FuelClientTest, DownloadWorld)
 {
   // Configure to use binary path as cache
@@ -1093,8 +1071,8 @@ TEST_F(FuelClientTest, DownloadWorld)
   ASSERT_TRUE(common::createDirectories("test_cache"));
 
   ServerConfig server;
-  server.SetUrl(common::URI(
-        "https://fuel.gazebosim.org"));
+  server.SetUrl(ignition::common::URI(
+        "https://fuel.ignitionrobotics.org"));
 
   ClientConfig config;
   config.AddServer(server);
@@ -1107,7 +1085,7 @@ TEST_F(FuelClientTest, DownloadWorld)
   // Download world from URL
   {
     // Unversioned URL should get the latest available version
-    common::URI url{"https://fuel.gazebosim.org/1.0/OpenRobotics/"
+    common::URI url{"https://fuel.ignitionrobotics.org/1.0/OpenRobotics/"
                     "worlds/Test world"};
 
     // Check it is not cached
@@ -1124,7 +1102,7 @@ TEST_F(FuelClientTest, DownloadWorld)
 
     // Check it was downloaded to `1`
     auto worldPath = common::joinPaths(common::cwd(), "test_cache",
-        "fuel.gazebosim.org", "openrobotics", "worlds", "test world");
+        "fuel.ignitionrobotics.org", "openrobotics", "worlds", "test world");
 
     EXPECT_EQ(path, common::joinPaths(worldPath, "2"));
     EXPECT_TRUE(common::exists(common::joinPaths(worldPath, "2")));
@@ -1143,7 +1121,7 @@ TEST_F(FuelClientTest, DownloadWorld)
   // Try using nonexistent URL
   {
     common::URI url{
-        "https://fuel.gazebosim.org/1.0/OpenRobotics/worlds/Bad world"};
+        "https://fuel.ignitionrobotics.org/1.0/OpenRobotics/worlds/Bad world"};
     std::string path;
     auto result = client.DownloadWorld(url, path);
     EXPECT_FALSE(result);
@@ -1162,7 +1140,7 @@ TEST_F(FuelClientTest, DownloadWorld)
 
 /////////////////////////////////////////////////
 // Windows doesn't support colons in filenames
-// https://github.com/gazebosim/gz-fuel-tools/issues/106
+// https://github.com/ignitionrobotics/ign-fuel-tools/issues/106
 TEST_F(FuelClientTest, CachedWorld)
 {
   // Configure to use binary path as cache and populate it
@@ -1352,7 +1330,7 @@ TEST_F(FuelClientTest, WorldDetails)
 
 /////////////////////////////////////////////////
 // Protocol "https" not supported or disabled in libcurl for Windows
-// https://github.com/gazebosim/gz-fuel-tools/issues/105
+// https://github.com/ignitionrobotics/ign-fuel-tools/issues/105
 TEST_F(FuelClientTest, Models)
 {
   ClientConfig config;
@@ -1372,7 +1350,7 @@ TEST_F(FuelClientTest, Models)
   }
 
   {
-    // Uses fuel.gazebosim.org by default
+    // Uses fuel.ignitionrobotics.org by default
     ModelIter iter = client.Models(serverConfig);
     EXPECT_TRUE(iter);
   }
@@ -1384,55 +1362,9 @@ TEST_F(FuelClientTest, Models)
   }
 }
 
-//////////////////////////////////////////////////
-TEST_F(FuelClientTest, ModelsCheckCached)
-{
-  ClientConfig config;
-  std::string cacheDir = common::joinPaths(PROJECT_BINARY_PATH, "test_cache");
-  common::removeAll(cacheDir );
-  ASSERT_TRUE(common::createDirectories(cacheDir));
-  config.SetCacheLocation(cacheDir);
-  FuelClient client(config);
-  ServerConfig serverConfig;
-  ModelIdentifier modelId;
-  modelId.SetOwner("openroboticstest");
-  std::vector<Model> modelInfos;
-  {
-    for (ModelIter iter = client.Models(modelId, true); iter; ++iter)
-    {
-      modelInfos.push_back(*iter);
-    }
-  }
-  ASSERT_FALSE(modelInfos.empty());
-  // Download one of the models to test the behavior of Models() with
-  // different values for _checkCache
-  EXPECT_TRUE(client.DownloadModel(modelInfos.front().Identification()));
-  {
-    std::size_t counter = 0;
-    for (ModelIter iter = client.Models(modelId, true); iter; ++iter, ++counter)
-    {
-    }
-    std::cout << "counter: " << counter << std::endl;
-    // Expect only one result with checkCache=true because we've downloaded only
-    // one model
-    EXPECT_EQ(counter, 1u);
-    EXPECT_GT(modelInfos.size(), counter);
-  }
-
-  {
-    std::size_t counter = 0;
-    for (ModelIter iter = client.Models(modelId, false); iter;
-         ++iter, ++counter)
-    {
-    }
-    std::cout << "counter: " << counter << std::endl;
-    EXPECT_EQ(counter, modelInfos.size());
-  }
-}
-
 /////////////////////////////////////////////////
 // Protocol "https" not supported or disabled in libcurl for Windows
-// https://github.com/gazebosim/gz-fuel-tools/issues/105
+// https://github.com/ignitionrobotics/ign-fuel-tools/issues/105
 TEST_F(FuelClientTest, Worlds)
 {
   ClientConfig config;
@@ -1452,7 +1384,7 @@ TEST_F(FuelClientTest, Worlds)
   }
 
   {
-    // Uses fuel.gazebosim.org by default
+    // Uses fuel.ignitionrobotics.org by default
     WorldIter iter = client.Worlds(serverConfig);
     EXPECT_TRUE(iter);
   }
@@ -1490,7 +1422,14 @@ TEST_F(FuelClientTest, DeleteModelFail)
   FuelClient client;
   ModelIdentifier modelId;
 
+#ifndef _WIN32
+# pragma GCC diagnostic push
+# pragma GCC diagnostic ignored "-Wdeprecated-declarations"
+#endif
   Result result = client.DeleteModel(modelId);
+#ifndef _WIN32
+# pragma GCC diagnostic pop
+#endif
   EXPECT_EQ(ResultType::DELETE_ERROR, result.Type());
 }
 
