@@ -20,13 +20,13 @@
 #include <fstream>
 #include <set>
 #include <string>
-#include <gz/common/Console.hh>
-#include <gz/common/Filesystem.hh>
-#include <gz/utilities/ExtraTestMacros.hh>
+#include <ignition/common/Console.hh>
+#include <ignition/common/Filesystem.hh>
+#include <ignition/utilities/ExtraTestMacros.hh>
 
-#include "gz/fuel_tools/ClientConfig.hh"
-#include "gz/fuel_tools/LocalCache.hh"
-#include "gz/fuel_tools/WorldIdentifier.hh"
+#include "ignition/fuel_tools/ClientConfig.hh"
+#include "ignition/fuel_tools/LocalCache.hh"
+#include "ignition/fuel_tools/WorldIdentifier.hh"
 
 #include "test/test_config.h"
 
@@ -88,7 +88,7 @@ void createLocal6Models(ClientConfig &_conf)
       common::joinPaths(serverPath,
       "trudy", "models", "tm2", "2", "model.config")));
 
-  ServerConfig srv;
+  ignition::fuel_tools::ServerConfig srv;
   srv.SetUrl(common::URI("http://localhost:8001/"));
   _conf.AddServer(srv);
 }
@@ -122,8 +122,8 @@ void createLocal3Models(ClientConfig &_conf)
       common::joinPaths(serverPath,
       "trudy", "models", "tm1", "3", "model.config")));
 
-  ServerConfig srv;
-  srv.SetUrl(common::URI("http://localhost:8007/"));
+  ignition::fuel_tools::ServerConfig srv;
+  srv.SetUrl(ignition::common::URI("http://localhost:8007/"));
   _conf.AddServer(srv);
 }
 
@@ -174,8 +174,8 @@ void createLocal6Worlds(ClientConfig &_conf)
       common::joinPaths(serverPath,
       "trudy", "worlds", "tm2", "2", "world.world")));
 
-  ServerConfig srv;
-  srv.SetUrl(common::URI("http://localhost:8001/"));
+  ignition::fuel_tools::ServerConfig srv;
+  srv.SetUrl(ignition::common::URI("http://localhost:8001/"));
   _conf.AddServer(srv);
 }
 
@@ -208,7 +208,7 @@ void createLocal3Worlds(ClientConfig &_conf)
       common::joinPaths(serverPath,
       "trudy", "worlds", "tm1", "3", "world.world")));
 
-  ServerConfig srv;
+  ignition::fuel_tools::ServerConfig srv;
   srv.SetUrl(common::URI("http://localhost:8007/"));
   _conf.AddServer(srv);
 }
@@ -218,7 +218,7 @@ class LocalCacheTest : public ::testing::Test
 {
   public: void SetUp() override
   {
-    common::Console::SetVerbosity(4);
+    ignition::common::Console::SetVerbosity(4);
   }
 };
 
@@ -234,7 +234,14 @@ TEST_F(LocalCacheTest, AllModels)
   createLocal6Models(conf);
   createLocal3Models(conf);
 
-  LocalCache cache(&conf);
+#ifndef _WIN32
+# pragma GCC diagnostic push
+# pragma GCC diagnostic ignored "-Wdeprecated-declarations"
+#endif
+  ignition::fuel_tools::LocalCache cache(&conf);
+#ifndef _WIN32
+# pragma GCC diagnostic pop
+#endif
 
   auto iter = cache.AllModels();
   std::set<std::string> uniqueNames;
@@ -263,7 +270,14 @@ TEST_F(LocalCacheTest, MatchingModels)
   createLocal6Models(conf);
   createLocal3Models(conf);
 
-  LocalCache cache(&conf);
+#ifndef _WIN32
+# pragma GCC diagnostic push
+# pragma GCC diagnostic ignored "-Wdeprecated-declarations"
+#endif
+  ignition::fuel_tools::LocalCache cache(&conf);
+#ifndef _WIN32
+# pragma GCC diagnostic pop
+#endif
 
   ModelIdentifier am1;
   am1.SetServer(conf.Servers().front());
@@ -307,12 +321,20 @@ TEST_F(LocalCacheTest, MatchingModel)
   conf.SetCacheLocation(common::joinPaths(common::cwd(), "test_cache"));
   createLocal6Models(conf);
 
-  LocalCache cache(&conf);
+#ifndef _WIN32
+# pragma GCC diagnostic push
+# pragma GCC diagnostic ignored "-Wdeprecated-declarations"
+#endif
+  ignition::fuel_tools::LocalCache cache(&conf);
+#ifndef _WIN32
+# pragma GCC diagnostic pop
+#endif
 
-  ServerConfig srv1;
+
+  ignition::fuel_tools::ServerConfig srv1;
   srv1.SetUrl(common::URI("http://localhost:8001/"));
 
-  ServerConfig srv2;
+  ignition::fuel_tools::ServerConfig srv2;
   srv2.SetUrl(common::URI("http://localhost:8002/"));
 
   ModelIdentifier am1;
@@ -323,7 +345,7 @@ TEST_F(LocalCacheTest, MatchingModel)
   ASSERT_TRUE(am1Model);
   EXPECT_EQ("alice", am1Model.Identification().Owner());
   EXPECT_EQ("am1", am1Model.Identification().Name());
-  EXPECT_EQ("http://localhost:8001",
+  EXPECT_EQ("http://localhost:8001/",
       am1Model.Identification().Server().Url().Str());
 
   ModelIdentifier tm2;
@@ -364,7 +386,15 @@ TEST_F(LocalCacheTest, AllWorlds)
   createLocal6Worlds(conf);
   createLocal3Worlds(conf);
 
-  LocalCache cache(&conf);
+#ifndef _WIN32
+# pragma GCC diagnostic push
+# pragma GCC diagnostic ignored "-Wdeprecated-declarations"
+#endif
+  ignition::fuel_tools::LocalCache cache(&conf);
+#ifndef _WIN32
+# pragma GCC diagnostic pop
+#endif
+
 
   auto iter = cache.AllWorlds();
   std::set<std::string> uniqueNames;
@@ -376,10 +406,10 @@ TEST_F(LocalCacheTest, AllWorlds)
   EXPECT_EQ(9u, uniqueNames.size());
 #ifdef _WIN32
   EXPECT_NE(uniqueNames.end(), uniqueNames.find(
-    common::joinPaths("localhost8001", "alice", "worlds", "am1")));
+    ignition::common::joinPaths("localhost8001", "alice", "worlds", "am1")));
 #else
   EXPECT_NE(uniqueNames.end(), uniqueNames.find(
-    common::joinPaths("localhost:8001", "alice", "worlds", "am1")));
+    ignition::common::joinPaths("localhost:8001", "alice", "worlds", "am1")));
 #endif
 }
 
@@ -397,7 +427,15 @@ TEST_F(LocalCacheTest, MatchingWorlds)
   createLocal6Worlds(conf);
   createLocal3Worlds(conf);
 
-  LocalCache cache(&conf);
+#ifndef _WIN32
+# pragma GCC diagnostic push
+# pragma GCC diagnostic ignored "-Wdeprecated-declarations"
+#endif
+  ignition::fuel_tools::LocalCache cache(&conf);
+#ifndef _WIN32
+# pragma GCC diagnostic pop
+#endif
+
 
   WorldIdentifier am1;
   am1.SetServer(conf.Servers().front());
@@ -429,13 +467,21 @@ TEST_F(LocalCacheTest, MatchingWorld)
   conf.SetCacheLocation(common::joinPaths(common::cwd(), "test_cache"));
   createLocal6Worlds(conf);
 
-  LocalCache cache(&conf);
+#ifndef _WIN32
+# pragma GCC diagnostic push
+# pragma GCC diagnostic ignored "-Wdeprecated-declarations"
+#endif
+  ignition::fuel_tools::LocalCache cache(&conf);
+#ifndef _WIN32
+# pragma GCC diagnostic pop
+#endif
 
-  ServerConfig srv1;
-  srv1.SetUrl(common::URI("http://localhost:8001/"));
 
-  ServerConfig srv2;
-  srv2.SetUrl(common::URI("http://localhost:8002/"));
+  ignition::fuel_tools::ServerConfig srv1;
+  srv1.SetUrl(ignition::common::URI("http://localhost:8001/"));
+
+  ignition::fuel_tools::ServerConfig srv2;
+  srv2.SetUrl(ignition::common::URI("http://localhost:8002/"));
 
   WorldIdentifier am1;
   am1.SetServer(srv1);
@@ -444,7 +490,7 @@ TEST_F(LocalCacheTest, MatchingWorld)
   EXPECT_TRUE(cache.MatchingWorld(am1));
   EXPECT_EQ("alice", am1.Owner());
   EXPECT_EQ("am1", am1.Name());
-  EXPECT_EQ("http://localhost:8001", am1.Server().Url().Str());
+  EXPECT_EQ("http://localhost:8001/", am1.Server().Url().Str());
 
   WorldIdentifier tm2;
   tm2.SetServer(srv1);
