@@ -19,14 +19,15 @@
 #include <regex>
 #include <string>
 #include <vector>
-#include <gz/common/Console.hh>
+#include <ignition/common/Console.hh>
 
-#include "gz/fuel_tools/ClientConfig.hh"
-#include "gz/fuel_tools/JSONParser.hh"
-#include "gz/fuel_tools/WorldIdentifier.hh"
-#include "gz/fuel_tools/WorldIter.hh"
-#include "gz/fuel_tools/WorldIterPrivate.hh"
-#include "gz/fuel_tools/RestClient.hh"
+#include "ignition/fuel_tools/ClientConfig.hh"
+#include "ignition/fuel_tools/JSONParser.hh"
+#include "ignition/fuel_tools/WorldIdentifier.hh"
+#include "ignition/fuel_tools/WorldIter.hh"
+#include "ignition/fuel_tools/RestClient.hh"
+
+#include "WorldIterPrivate.hh"
 
 using namespace ignition;
 using namespace fuel_tools;
@@ -129,7 +130,7 @@ WorldIterRestIds::WorldIterRestIds(const Rest &_rest,
     // Get the next page from the headers.
     if (resp.headers.find("Link") != resp.headers.end())
     {
-      std::vector<std::string> links = common::split(
+      std::vector<std::string> links = ignition::common::split(
           resp.headers["Link"], ",");
       for (const auto &l : links)
       {
@@ -230,6 +231,12 @@ WorldIdentifier *WorldIter::operator->()
   return &(this->dataPtr->worldId);
 }
 
+//////////////////////////////////////////////////
+WorldIdentifier &WorldIter::operator*()
+{
+  return this->dataPtr->worldId;
+}
+
 //////////////////////////////////////////////////
 WorldIter::operator WorldIdentifier() const
 {
