@@ -22,10 +22,10 @@
 #include <fstream>
 #include <string>
 
-#include <gz/common/Console.hh>
-#include <gz/common/Filesystem.hh>
+#include <ignition/common/Console.hh>
+#include <ignition/common/Filesystem.hh>
 
-#include "gz/fuel_tools/Zip.hh"
+#include "ignition/fuel_tools/Zip.hh"
 
 using namespace ignition;
 using namespace fuel_tools;
@@ -35,20 +35,20 @@ using namespace fuel_tools;
 bool CompressFile(zip *_archive, const std::string &_file,
     const std::string &_entry)
 {
-  if (common::isDirectory(_file))
+  if (ignition::common::isDirectory(_file))
   {
-    if (zip_dir_add(_archive, _entry.c_str(), 0) < 0)
+    if (zip_add_dir(_archive, _entry.c_str()) < 0)
     {
       ignerr << "Error adding directory to zip: " << _file << std::endl;
       return false;
     }
 
-    common::DirIter endIt;
-    for (common::DirIter dirIt(_file); dirIt != endIt; ++dirIt)
+    ignition::common::DirIter endIt;
+    for (ignition::common::DirIter dirIt(_file); dirIt != endIt; ++dirIt)
     {
       std::string file = *dirIt;
-      std::string entryName = common::joinPaths(_entry,
-          common::basename(file));
+      std::string entryName = ignition::common::joinPaths(_entry,
+          ignition::common::basename(file));
 
       if (!CompressFile(_archive, file, entryName))
       {
@@ -56,7 +56,7 @@ bool CompressFile(zip *_archive, const std::string &_file,
       }
     }
   }
-  else if (common::isFile(_file))
+  else if (ignition::common::isFile(_file))
   {
     std::ifstream in(_file.c_str(),
         std::ifstream::ate | std::ifstream::binary);
@@ -69,7 +69,7 @@ bool CompressFile(zip *_archive, const std::string &_file,
       return false;
     }
 
-    if (zip_file_add(_archive, _entry.c_str(), source, 0)
+    if (zip_add(_archive, _entry.c_str(), source)
         < 0)
     {
       ignerr << "Error adding file to zip: " << _file << std::endl;
@@ -83,7 +83,7 @@ bool CompressFile(zip *_archive, const std::string &_file,
 /////////////////////////////////////////////////
 bool Zip::Compress(const std::string &_src, const std::string &_dst)
 {
-  if (!common::exists(_src))
+  if (!ignition::common::exists(_src))
   {
     ignerr << "Directory does not exist: " << _src << std::endl;
     return false;
@@ -97,7 +97,7 @@ bool Zip::Compress(const std::string &_src, const std::string &_dst)
     return false;
   }
 
-  std::string entry = common::basename(_src);
+  std::string entry = ignition::common::basename(_src);
   if (!CompressFile(archive, _src, entry))
   {
     ignerr << "Error compressing file: " << _src << std::endl;
@@ -113,7 +113,7 @@ bool Zip::Compress(const std::string &_src, const std::string &_dst)
 bool Zip::Extract(const std::string &_src,
     const std::string &_dst)
 {
-  if (!common::exists(_src))
+  if (!ignition::common::exists(_src))
   {
     ignerr << "Source archive does not exist: " << _src << std::endl;
     return false;
@@ -138,13 +138,13 @@ bool Zip::Extract(const std::string &_src,
 
     auto entryname = std::string(sb.name);
     common::changeFromUnixPath(entryname);
-    std::string dst = common::joinPaths(_dst, entryname);
+    std::string dst = ignition::common::joinPaths(_dst, entryname);
 
     // Check if the entryname contains a / at the end. if so it's a directory
-    auto pos = entryname.rfind(common::separator(""));
+    auto pos = entryname.rfind(ignition::common::separator(""));
     if (pos != std::string::npos && pos == (entryname.size() - 1))
     {
-      if (!common::createDirectories(dst))
+      if (!ignition::common::createDirectories(dst))
       {
         ignerr << "Error creating directory [" << dst << "]. "
                << "Do you have the right permissions?" << std::endl;
