@@ -104,9 +104,7 @@ TEST_F(CmdLine, ModelListConfigServerUgly)
 /////////////////////////////////////////////////
 // Protocol "https" not supported or disabled in libcurl for Windows
 // https://github.com/ignitionrobotics/ign-fuel-tools/issues/105
-// https://github.com/gazebosim/gz-fuel-tools/issues/254
-TEST_F(CmdLine,
-       DETAIL_IGN_UTILS_ADD_DISABLED_PREFIX(ModelListConfigServerPretty))
+TEST_F(CmdLine, ModelListConfigServerPretty)
 {
   EXPECT_TRUE(listModels("https://staging-fuel.ignitionrobotics.org"));
 
@@ -128,9 +126,7 @@ TEST_F(CmdLine,
 /////////////////////////////////////////////////
 // Protocol "https" not supported or disabled in libcurl for Windows
 // https://github.com/ignitionrobotics/ign-fuel-tools/issues/105
-// https://github.com/gazebosim/gz-fuel-tools/issues/254
-TEST_F(CmdLine,
-       DETAIL_IGN_UTILS_ADD_DISABLED_PREFIX(ModelListConfigServerPrettyOwner))
+TEST_F(CmdLine, ModelListConfigServerPrettyOwner)
 {
   EXPECT_TRUE(listModels("https://staging-fuel.ignitionrobotics.org",
       "openrobotics"));
@@ -256,9 +252,7 @@ TEST_F(CmdLine, WorldListFail)
 /////////////////////////////////////////////////
 // Protocol "https" not supported or disabled in libcurl for Windows
 // https://github.com/ignitionrobotics/ign-fuel-tools/issues/105
-// https://github.com/gazebosim/gz-fuel-tools/issues/254
-TEST_F(CmdLine,
-       DETAIL_IGN_UTILS_ADD_DISABLED_PREFIX(WorldListConfigServerUgly))
+TEST_F(CmdLine, WorldListConfigServerUgly)
 {
   EXPECT_TRUE(listWorlds(
         "https://staging-fuel.ignitionrobotics.org", "", "true"));
@@ -273,9 +267,7 @@ TEST_F(CmdLine,
 /////////////////////////////////////////////////
 // Protocol "https" not supported or disabled in libcurl for Windows
 // https://github.com/ignitionrobotics/ign-fuel-tools/issues/105
-// https://github.com/gazebosim/gz-fuel-tools/issues/254
-TEST_F(CmdLine,
-       DETAIL_IGN_UTILS_ADD_DISABLED_PREFIX(WorldListConfigServerPretty))
+TEST_F(CmdLine, WorldListConfigServerPretty)
 {
   EXPECT_TRUE(listWorlds("https://staging-fuel.ignitionrobotics.org"));
 
